'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cleanReactProps = require('clean-react-props');

var _cleanReactProps2 = _interopRequireDefault(_cleanReactProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var SECOND = 1000;
var MINUTE = 60 * 1000;
var HOUR = 60 * 60 * 1000;

var Timecode = function (_Component) {
  _inherits(Timecode, _Component);

  function Timecode() {
    _classCallCheck(this, Timecode);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Timecode.prototype.formatTimecode = function formatTimecode(_ref) {
    var hours = _ref.hours,
        minutes = _ref.minutes,
        seconds = _ref.seconds,
        milliseconds = _ref.milliseconds;
    var format = this.props.format;


    switch (format) {
      case 'HH:mm:ss.sss':
        return (hours < 10 ? '0' + hours : hours) + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;

      case 'H:mm:ss.sss':
        return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;

      case 'H:?mm:ss.sss':
        if (hours) {
          return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;
        }

        return (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;

      case 'H:?m:ss.sss':
        if (hours) {
          return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;
        }

        return minutes + ':' + (seconds < 10 ? '0' + seconds : seconds) + '.' + (milliseconds / 1000).toFixed(3) * 1000;

      case 'HH:mm:ss':
        return (hours < 10 ? '0' + hours : hours) + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds);

      case 'H:mm:ss':
        return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds);

      case 'H:?mm:ss':
        if (hours) {
          return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds);
        }

        return (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds);

      case 'H:mm':
        return hours + ':' + (minutes < 10 ? '0' + minutes : minutes);

      case 'H:?m:ss':
      default:
        if (hours) {
          return hours + ':' + (minutes < 10 ? '0' + minutes : minutes) + ':' + (seconds < 10 ? '0' + seconds : seconds);
        }

        return minutes + ':' + (seconds < 10 ? '0' + seconds : seconds);
    }
  };

  Timecode.prototype.render = function render() {
    var _props = this.props,
        element = _props.element,
        time = _props.time;


    var milliseconds = time;

    var hours = milliseconds > HOUR ? Math.floor(milliseconds / HOUR) : 0;

    if (hours) {
      milliseconds -= hours * HOUR;
    }

    var minutes = milliseconds > MINUTE ? Math.floor(milliseconds / MINUTE) : 0;

    if (minutes) {
      milliseconds -= minutes * MINUTE;
    }

    var seconds = milliseconds > SECOND ? Math.floor(milliseconds / SECOND) : 0;

    if (seconds) {
      milliseconds -= seconds * SECOND;
    }

    var ElementTag = '' + element;

    return _react2.default.createElement(
      ElementTag,
      (0, _cleanReactProps2.default)(this.props),
      this.formatTimecode({ hours: hours, minutes: minutes, seconds: seconds, milliseconds: milliseconds })
    );
  };

  return Timecode;
}(_react.Component);

Timecode.propTypes = {
  element: _propTypes2.default.string,
  format: _propTypes2.default.string,
  time: _propTypes2.default.number
};

Timecode.defaultProps = {
  element: 'span',
  format: 'H:?m:ss',
  time: 0
};

exports.default = Timecode;